@@ -22,7 +22,8 @@ class BaseExplainer(ABC):
 
         self.model_type = model.config.model_type
 
-        self.device = torch.device("cuda:0" if torch.cuda.is_available() else "cpu")
+        self.device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
+        self.model.to(self.device)
 
     @abstractmethod
     def encode(self, text: str = None):
